==> ejc-settlementmanage-api-3.0.0-20221012.072025-74-sources.jar: com/ejianc/business/settlementmanage/api/ICostManageApi.java <==
package com.ejianc.business.settlementmanage.api;

import com.ejianc.business.settlementmanage.hystrix.CostManageHystrix;
import com.ejianc.business.settlementmanage.hystrix.SettlementHystrix;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.math.BigDecimal;

@FeignClient(name= "ejc-settlementmanage-web", url="${common.env.feign-client-url}", path="ejc-settlementmanage-web", fallback = CostManageHystrix.class)
public interface ICostManageApi {

    /**
     * 成本管理-成本核算:部品部件及材料费
     * @param projectId
     * @param time
     * @return
     */
    @GetMapping(value = "/api/costmanage/queryCostaccountPartmaterial")
    CommonResponse<BigDecimal> queryCostaccountPartmaterial(@RequestParam("projectId") Long projectId, @RequestParam("time") String time);

    /**
     * 成本管理-成本核算:机械费
     * @param projectId
     * @param time
     * @return
     */
    @GetMapping(value = "/api/costmanage/queryCostaccountMechanical")
    CommonResponse<BigDecimal> queryCostaccountMechanical(@RequestParam("projectId") Long projectId,@RequestParam("time") String time);

    /**
     * 成本管理-项目部商务经理月度报告：竣工工程结算额
     * @param contractId
     * @return
     */
    @GetMapping(value = "/api/costmanage/queryProjectreportSettlement")
    CommonResponse<BigDecimal> queryProjectreportSettlement(@RequestParam("contractId") Long contractId);
}

==> ejc-settlementmanage-api-3.0.0-20221128.112438-115-sources.jar: com/ejianc/business/settlementmanage/api/ICostManageApi.java <==
package com.ejianc.business.settlementmanage.api;

import com.ejianc.business.settlementmanage.hystrix.CostManageHystrix;
import com.ejianc.business.settlementmanage.hystrix.SettlementHystrix;
import com.ejianc.business.settlementmanage.vo.LaborCostRequestVO;
import com.ejianc.business.settlementmanage.vo.LaborCostVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.Map;

@FeignClient(name= "ejc-settlementmanage-web", url="${common.env.feign-client-url}", path="ejc-settlementmanage-web", fallback = CostManageHystrix.class)
public interface ICostManageApi {

    /**
     * 成本管理-成本核算:部品部件及材料费
     * @param projectId
     * @param time
     * @return
     */
    @GetMapping(value = "/api/costmanage/queryCostaccountPartmaterial")
    CommonResponse<BigDecimal> queryCostaccountPartmaterial(@RequestParam("projectId") Long projectId, @RequestParam("time") String time);

    /**
     * 成本管理-成本核算:机械费
     * @param projectId
     * @param time
     * @return
     */
    @GetMapping(value = "/api/costmanage/queryCostaccountMechanical")
    CommonResponse<BigDecimal> queryCostaccountMechanical(@RequestParam("projectId") Long projectId,@RequestParam("time") String time);

    /**
     * 成本管理-项目部商务经理月度报告：竣工工程结算额
     * @param contractId
     * @return
     */
    @GetMapping(value = "/api/costmanage/queryProjectreportSettlement")
    CommonResponse<BigDecimal> queryProjectreportSettlement(@RequestParam("contractId") Long contractId);
    /**
     *项目月度成本分析报告
     * 获取结算书金额
     * @param contractId
     * @return
     */
    @PostMapping(value = "/api/costmanage/queryLabor")
    @ResponseBody
    CommonResponse<Map<String,LaborCostVO>> queryLabor(@RequestBody LaborCostRequestVO laborCostRequestVO);
}
